Contact Us — Kivy v1.0.1-dev documentation

# Contact Us

You can contact us in several different ways:

## Issue Tracker

If you found an issue with the code or have a feature request, please see our issue tracker. If there is no issue yet that matches your inquiry, feel free to create a new one. Please make sure you receive the mails that github sends if we comment on the issue in case we need more information. For bugs, please provide all the information necessary, like the operating system you’re using, the full error message or any other logs, a description what you did to trigger the bug and what the actual bug was, and anything else that might be of interest. We can only help if you precisely tell us what the actual problem is, obviously.

## Mail

For users of our framework, there is a mailing list for support inquiries on Google Groups. Use this list if you have issues with your Kivy-based app. Also, we have a mailing list for matters that deal with development of the actual Kivy framework code on Google Groups.

## IRC

#kivy on irc.freenode.net

IRC is great for real-time communication, but please make sure to wait after you asked your question. If you just join, ask and quit we have no way of knowing who you were and where we’re supposed to send our answer to. Also, keep in mind we’re mostly based in Europe, so take into account any timezone issues. If you’re unlucky more than once, try the mailing list.

If you don’t have an IRC client, you can also use Freenode’s web chat, but please, don’t close the browser window too soon. Just enter `#kivy` in the channels field.